djangocms_ads
=============

Google adverts for django-cms.

Provides plugins to add ad slots to the ``<head>`` tag and then a plugin to create
the advert element in the page content.

Plugin templates can be extended using the ``DJANGOCMS_ADS_TEMPLATES`` setting.
